pub struct Platform(/* private fields */);Expand description
Abstraction for SYCL platform.
The Platform struct encapsulates a single SYCL platform on which SYCL kernel functions may be executed.
A SYCL platform must be associated with a single SYCL backend.
A Platform is also associated with one or more SYCL devices associated with the same SYCL backend.
Implementations